//--------------------------------------------------------------
// File     : main.c
// Datum    : 18.08.2013
// Version  : 1.0
// Autor    : UB
// EMail    : mc-4u(@)t-online.de
// Web      : www.mikrocontroller-4u.de
// CPU      : STM32F4
// IDE      : CooCox CoIDE 1.7.0
// Module   : CMSIS_BOOT, M4_CMSIS_CORE
// Funktion : Demo der MP3-Lib (per USB_MSC_Host und FATFS)
// Hinweis  : Diese zwei Files muessen auf 8MHz stehen
//              "cmsis_boot/stm32f4xx.h"
//              "cmsis_boot/system_stm32f4xx.c"
//
// Compiler Optimization auf -O3 einstellen !!
//--------------------------------------------------------------

#include "main.h"
#include "stm32_ub_usb_msc_host.h"
#include "stm32_ub_cs43l22_mp3_fatfs.h"

int main(void)
{
  uint8_t play_mode=0;

  SystemInit(); // Quarz Einstellungen aktivieren

  // Init vom USB-OTG-Port als MSC-HOST
  // (zum lesen/schreiben auf einen USB-Stick)
  UB_USB_MSC_HOST_Init();

  // Init vom CS43L22 (im MP3 Mode)
  if(UB_CS43L22_InitMP3()==SUCCESS) {
    play_mode=1; // init war ok
  }

  while(1)
  {
    // pollen vom USB-Status
    if(UB_USB_MSC_HOST_Do()==USB_MSC_DEV_CONNECTED) {
	  // wenn USB-Stick erkannt wurde

      // MP3-Funktion zum abspielen zyklisch aufrufen
      UB_CS43L22_PlayMP3Do();

      if(play_mode==1) {
        // Media einmal mounten
        if(UB_Fatfs_Mount(USB_0)==FATFS_OK) {
          play_mode=2;
          // abspielen vom MP3-File von USB in einer Endlosloop
          UB_CS43L22_PlayMP3Loop("skinny.mp3",70);
        }
      }
    }
    else {
	  // kein USB-Stick vorhanden
      if(play_mode>1) {
        play_mode=1;
        // Media unmounten
        UB_Fatfs_UnMount(USB_0);
      }
    }
  }
}

